==> crow-2.11.3.tar.bz2: crow-2.11.3/crow/headers.h <==
/*
 *  Crow, a GUI designer for GTK+
 *  Copyright (c) 2005-2008 Maxim Udushlivy
 *
 *  Permission is hereby granted, free of charge, to any person 
 *  obtaining a copy of this software and associated documentation 
 *  files (the "Software"), to deal in the Software without 
 *  restriction, including without limitation the rights to use, copy, 
 *  modify, merge, publish, distribute, sublicense, and/or sell copies 
 *  of the Software, and to permit persons to whom the Software is 
 *  furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be 
 *  included in all copies or substantial portions of the Software.
 *
 *  The software is provided "as is", without warranty of any kind, 
 *  express or implied, including but not limited to the warranties of 
 *  merchantability, fitness for a particular purpose and 
 *  noninfringement. In no event shall the authors or copyright 
 *  holders be liable for any claim, damages or other liability, 
 *  whether in an action of contract, tort or otherwise, arising from, 
 *  out of or in connection with the software or the use or other 
 *  dealings in the software.
 */

#ifndef CROW_HEADERS_H
#define CROW_HEADERS_H

#ifdef CROW_SANDBOX
	#define G_DISABLE_DEPRECATED
	#define GDK_DISABLE_DEPRECATED
	#define GDK_PIXBUF_DISABLE_DEPRECATED
	#define PANGO_DISABLE_DEPRECATED
	#define GTK_DISABLE_DEPRECATED
	#define GTKMM_DISABLE_DEPRECATED
#endif

#include <gtk/gtk.h>

#include <libintl.h>

#ifdef __GNUC__
	#include <cxxabi.h>
#endif

#include <sigc++/sigc++.h>
#include <gtkmm.h>

#include <cassert>
#include <map>
#include <vector>
#include <string>
#include <list>
#include <set>
#include <iostream>
#include <sstream>
#include <iomanip>

#endif

==> crow-2.13.0.tar.bz2: crow-2.13.0/crow/headers.h <==
/*
 *  Crow, a GUI designer for GTK+
 *  Copyright (c) 2005-2009 Maxim Udushlivy
 *
 *  Permission is hereby granted, free of charge, to any person
 *  obtaining a copy of this software and associated documentation
 *  files (the "Software"), to deal in the Software without
 *  restriction, including without limitation the rights to use, copy,
 *  modify, merge, publish, distribute, sublicense, and/or sell copies
 *  of the Software, and to permit persons to whom the Software is
 *  furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be
 *  included in all copies or substantial portions of the Software.
 *
 *  The software is provided "as is", without warranty of any kind,
 *  express or implied, including but not limited to the warranties of
 *  merchantability, fitness for a particular purpose and
 *  noninfringement. In no event shall the authors or copyright
 *  holders be liable for any claim, damages or other liability,
 *  whether in an action of contract, tort or otherwise, arising from,
 *  out of or in connection with the software or the use or other
 *  dealings in the software.
 */

#ifndef CROW_HEADERS_H
#define CROW_HEADERS_H

#ifdef CROW_SANDBOX
	#define G_DISABLE_DEPRECATED
	#define GDK_DISABLE_DEPRECATED
	#define GDK_PIXBUF_DISABLE_DEPRECATED
	#define PANGO_DISABLE_DEPRECATED
	//#define GTK_DISABLE_DEPRECATED
	#define GLIBMM_DISABLE_DEPRECATED
	#define GTKMM_DISABLE_DEPRECATED
#endif

#include <gtk/gtk.h>

#include <libintl.h>

#ifdef __GNUC__
	#include <cxxabi.h>
#endif

#include <sigc++/sigc++.h>
#include <gtkmm.h>

#include <boost/format.hpp>
#include <boost/tokenizer.hpp>

#include <cassert>
#include <map>
#include <vector>
#include <string>
#include <list>
#include <set>
#include <iostream>
#include <sstream>
#include <iomanip>

#endif
